// Copyright 2014 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Generated from template:
//   templates/web_origin_trials.cc.tmpl
// and input files:
//   ../../../../../src/3rdparty/chromium/third_party/blink/renderer/platform/runtime_enabled_features.json5


#include "third_party/blink/public/web/web_origin_trials.h"

#include "third_party/blink/renderer/core/dom/document.h"
#include "third_party/blink/renderer/core/execution_context/execution_context.h"
#include "third_party/blink/public/mojom/origin_trial_feature/origin_trial_feature.mojom-shared.h"
#include "third_party/blink/public/common/origin_trials/origin_trials.h"
#include "third_party/blink/public/platform/web_string.h"
#include "third_party/blink/public/web/web_document.h"

namespace blink {

bool WebOriginTrials::isTrialEnabled(const WebDocument* web_document, const WebString& trial) {
  if (!web_document) return false;
  if (!origin_trials::IsTrialValid(trial.Utf8()))
    return false;
  Document* document = *web_document;
  for (mojom::blink::OriginTrialFeature feature : origin_trials::FeaturesForTrial(trial.Utf8())) {
    switch (feature) {
      case mojom::blink::OriginTrialFeature::kAdInterestGroupAPI:
        if (!RuntimeEnabledFeatures::AdInterestGroupAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kAIPromptAPIForExtension:
        if (!RuntimeEnabledFeatures::AIPromptAPIForExtensionEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kAISummarizationAPI:
        if (!RuntimeEnabledFeatures::AISummarizationAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kAppTitle:
        if (!RuntimeEnabledFeatures::AppTitleEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kAttributionReportingInterface:
        if (!RuntimeEnabledFeatures::AttributionReportingInterfaceEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kAutoDarkMode:
        if (!RuntimeEnabledFeatures::AutoDarkModeEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kBackForwardCacheExperimentHTTPHeader:
        if (!RuntimeEnabledFeatures::BackForwardCacheExperimentHTTPHeaderEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kBackForwardCacheNotRestoredReasons:
        if (!RuntimeEnabledFeatures::BackForwardCacheNotRestoredReasonsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kBuiltInAIAPI:
        if (!RuntimeEnabledFeatures::BuiltInAIAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kCacheStorageCodeCacheHint:
        if (!RuntimeEnabledFeatures::CacheStorageCodeCacheHintEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kCanvas2dMesh:
        if (!RuntimeEnabledFeatures::Canvas2dMeshEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kCapturedSurfaceControl:
        if (!RuntimeEnabledFeatures::CapturedSurfaceControlEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kCoopRestrictProperties:
        if (!RuntimeEnabledFeatures::CoopRestrictPropertiesEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDatabase:
        if (!RuntimeEnabledFeatures::DatabaseEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDeprecateUnloadOptOut:
        if (!RuntimeEnabledFeatures::DeprecateUnloadOptOutEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDevicePosture:
        if (!RuntimeEnabledFeatures::DevicePostureEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDigitalGoods:
        if (!RuntimeEnabledFeatures::DigitalGoodsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDisableDifferentOriginSubframeDialogSuppression:
        if (!RuntimeEnabledFeatures::DisableDifferentOriginSubframeDialogSuppressionEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDisableHardwareNoiseSuppression:
        if (!RuntimeEnabledFeatures::DisableHardwareNoiseSuppressionEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDisableReduceAcceptLanguage:
        if (!RuntimeEnabledFeatures::DisableReduceAcceptLanguageEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDisableThirdPartyStoragePartitioning2:
        if (!RuntimeEnabledFeatures::DisableThirdPartyStoragePartitioning2Enabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDocumentPolicyIncludeJSCallStacksInCrashReports:
        if (!RuntimeEnabledFeatures::DocumentPolicyIncludeJSCallStacksInCrashReportsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kDocumentPolicyNegotiation:
        if (!RuntimeEnabledFeatures::DocumentPolicyNegotiationEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kElementCapture:
        if (!RuntimeEnabledFeatures::ElementCaptureEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kFedCmAuthz:
        if (!RuntimeEnabledFeatures::FedCmAuthzEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kFedCmButtonMode:
        if (!RuntimeEnabledFeatures::FedCmButtonModeEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kFedCmMultipleIdentityProviders:
        if (!RuntimeEnabledFeatures::FedCmMultipleIdentityProvidersEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kFedCmWithStorageAccessAPI:
        if (!RuntimeEnabledFeatures::FedCmWithStorageAccessAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kFetchLaterAPI:
        if (!RuntimeEnabledFeatures::FetchLaterAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kFileSystemObserver:
        if (!RuntimeEnabledFeatures::FileSystemObserverEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kFledgeBiddingAndAuctionServerAPI:
        if (!RuntimeEnabledFeatures::FledgeBiddingAndAuctionServerAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kFocusgroup:
        if (!RuntimeEnabledFeatures::FocusgroupEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kGetAllScreensMedia:
        if (!RuntimeEnabledFeatures::GetAllScreensMediaEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kHrefTranslate:
        if (!RuntimeEnabledFeatures::HrefTranslateEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kJavaScriptCompileHintsMagicRuntime:
        if (!RuntimeEnabledFeatures::JavaScriptCompileHintsMagicRuntimeEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kKeyboardFocusableScrollersOptOut:
        if (!RuntimeEnabledFeatures::KeyboardFocusableScrollersOptOutEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kLanguageDetectionAPI:
        if (!RuntimeEnabledFeatures::LanguageDetectionAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kLimitThirdPartyCookies:
        if (!RuntimeEnabledFeatures::LimitThirdPartyCookiesEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kMediaCaptureBackgroundBlur:
        if (!RuntimeEnabledFeatures::MediaCaptureBackgroundBlurEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kMediaCaptureConfigurationChange:
        if (!RuntimeEnabledFeatures::MediaCaptureConfigurationChangeEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kMediaPreviewsOptOut:
        if (!RuntimeEnabledFeatures::MediaPreviewsOptOutEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kMediaSourceExtensionsForWebCodecs:
        if (!RuntimeEnabledFeatures::MediaSourceExtensionsForWebCodecsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kMutationEvents:
        if (!RuntimeEnabledFeatures::MutationEventsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kNavigationId:
        if (!RuntimeEnabledFeatures::NavigationIdEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kNotificationTriggers:
        if (!RuntimeEnabledFeatures::NotificationTriggersEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPI:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIBrowserReadWrite:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIBrowserReadWriteEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIDeprecation:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIDeprecationEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIExpiryGracePeriod:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIExpiryGracePeriodEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIExpiryGracePeriodThirdParty:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIExpiryGracePeriodThirdPartyEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIImplied:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIImpliedEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIInvalidOS:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIInvalidOSEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPINavigation:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPINavigationEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIPersistentExpiryGracePeriod:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIPersistentExpiryGracePeriodEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIPersistentFeature:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIPersistentFeatureEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIPersistentInvalidOS:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIPersistentInvalidOSEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIPersistentThirdPartyDeprecationFeature:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIPersistentThirdPartyDeprecationFeatureEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kOriginTrialsSampleAPIThirdParty:
        if (!RuntimeEnabledFeatures::OriginTrialsSampleAPIThirdPartyEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPageFreezeOptIn:
        if (!RuntimeEnabledFeatures::PageFreezeOptInEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPageFreezeOptOut:
        if (!RuntimeEnabledFeatures::PageFreezeOptOutEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kParakeet:
        if (!RuntimeEnabledFeatures::ParakeetEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPerMethodCanMakePaymentQuota:
        if (!RuntimeEnabledFeatures::PerMethodCanMakePaymentQuotaEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPermissionElement:
        if (!RuntimeEnabledFeatures::PermissionElementEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPNaCl:
        if (!RuntimeEnabledFeatures::PNaClEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPrefixedVideoFullscreen:
        if (!RuntimeEnabledFeatures::PrefixedVideoFullscreenEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPrivateNetworkAccessNonSecureContextsAllowed:
        if (!RuntimeEnabledFeatures::PrivateNetworkAccessNonSecureContextsAllowedEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPrivateNetworkAccessPermissionPrompt:
        if (!RuntimeEnabledFeatures::PrivateNetworkAccessPermissionPromptEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kPrivateStateTokens:
        if (!RuntimeEnabledFeatures::PrivateStateTokensEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kProtectedOriginTrialsSampleAPI:
        if (!RuntimeEnabledFeatures::ProtectedOriginTrialsSampleAPIEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kProtectedOriginTrialsSampleAPIImplied:
        if (!RuntimeEnabledFeatures::ProtectedOriginTrialsSampleAPIImpliedEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kReduceAcceptLanguage:
        if (!RuntimeEnabledFeatures::ReduceAcceptLanguageEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kRtcAudioJitterBufferMaxPackets:
        if (!RuntimeEnabledFeatures::RtcAudioJitterBufferMaxPacketsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kRTCEncodedFrameSetMetadata:
        if (!RuntimeEnabledFeatures::RTCEncodedFrameSetMetadataEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kRTCLegacyCallbackBasedGetStats:
        if (!RuntimeEnabledFeatures::RTCLegacyCallbackBasedGetStatsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kRTCStatsRelativePacketArrivalDelay:
        if (!RuntimeEnabledFeatures::RTCStatsRelativePacketArrivalDelayEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kSecurePaymentConfirmationOptOut:
        if (!RuntimeEnabledFeatures::SecurePaymentConfirmationOptOutEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kServiceWorkerStaticRouter:
        if (!RuntimeEnabledFeatures::ServiceWorkerStaticRouterEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kSignatureBasedIntegrity:
        if (!RuntimeEnabledFeatures::SignatureBasedIntegrityEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kSkipPreloadScanning:
        if (!RuntimeEnabledFeatures::SkipPreloadScanningEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kSoftNavigationHeuristics:
        if (!RuntimeEnabledFeatures::SoftNavigationHeuristicsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kSpeculationRulesPrefetchFuture:
        if (!RuntimeEnabledFeatures::SpeculationRulesPrefetchFutureEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kStandardizedBrowserZoomOptOut:
        if (!RuntimeEnabledFeatures::StandardizedBrowserZoomOptOutEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kStorageAccessHeader:
        if (!RuntimeEnabledFeatures::StorageAccessHeaderEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kTextFragmentIdentifiers:
        if (!RuntimeEnabledFeatures::TextFragmentIdentifiersEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kTopLevelTpcd:
        if (!RuntimeEnabledFeatures::TopLevelTpcdEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kTouchEventFeatureDetection:
        if (!RuntimeEnabledFeatures::TouchEventFeatureDetectionEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kTpcd:
        if (!RuntimeEnabledFeatures::TpcdEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kTranslationAPIEntryPoint:
        if (!RuntimeEnabledFeatures::TranslationAPIEntryPointEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kUnrestrictedSharedArrayBuffer:
        if (!RuntimeEnabledFeatures::UnrestrictedSharedArrayBufferEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kViewportSegments:
        if (!RuntimeEnabledFeatures::ViewportSegmentsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebAppLaunchQueue:
        if (!RuntimeEnabledFeatures::WebAppLaunchQueueEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebAppScopeExtensions:
        if (!RuntimeEnabledFeatures::WebAppScopeExtensionsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebAppUrlHandling:
        if (!RuntimeEnabledFeatures::WebAppUrlHandlingEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebAssemblyJSPromiseIntegration:
        if (!RuntimeEnabledFeatures::WebAssemblyJSPromiseIntegrationEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebAssemblyJSStringBuiltins:
        if (!RuntimeEnabledFeatures::WebAssemblyJSStringBuiltinsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebAuthenticationAttestationFormats:
        if (!RuntimeEnabledFeatures::WebAuthenticationAttestationFormatsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebGPUSubgroupsFeatures:
        if (!RuntimeEnabledFeatures::WebGPUSubgroupsFeaturesEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebIdentityDigitalCredentials:
        if (!RuntimeEnabledFeatures::WebIdentityDigitalCredentialsEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebTransportCustomCertificates:
        if (!RuntimeEnabledFeatures::WebTransportCustomCertificatesEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebViewXRequestedWithDeprecation:
        if (!RuntimeEnabledFeatures::WebViewXRequestedWithDeprecationEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebXRImageTracking:
        if (!RuntimeEnabledFeatures::WebXRImageTrackingEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      case mojom::blink::OriginTrialFeature::kWebXRPlaneDetection:
        if (!RuntimeEnabledFeatures::WebXRPlaneDetectionEnabled(
                document->GetExecutionContext())) {
          return false;
        }
        break;
      default:
        break;
    }
  }
  return true;
}


} // namespace blink
